@@ -12,7 +12,7 @@
 "bor" <-
 function(S=35,T=25,P=0){
 
-bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94   
-
-	cat("bor",bor," mol/kg\n");
-	}
+bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
+attr(bor,"unit") <- "mol/kg"
+print(bor);
+}
